pub struct TraceRequest {Show 13 fields
pub from_: Vec<Address>,
pub to: Vec<Address>,
pub address: Vec<Address>,
pub call_type: Vec<String>,
pub reward_type: Vec<String>,
pub type_: Vec<String>,
pub sighash: Vec<Sighash>,
pub author: Vec<Address>,
pub trace_method: TraceMethod,
pub include_transactions: bool,
pub include_transaction_logs: bool,
pub include_transaction_traces: bool,
pub include_blocks: bool,
}Expand description
Request for the trace pipeline (trace_block / debug_traceBlockByNumber).
Filter fields (from_, to, call_type, etc.) are not supported by
the RPC client — the provider returns all traces per block. Populate
these only if using a tiders client that supports server-side filtering.
Fields
from_: Vec<Address>to: Vec<Address>address: Vec<Address>call_type: Vec<String>reward_type: Vec<String>type_: Vec<String>sighash: Vec<Sighash>trace_method: TraceMethodWhich RPC method to use for fetching traces.
include_transactions: boolAlso fetch transactions for the same block range.
include_transaction_logs: boolAlso fetch logs for the same block range.
include_transaction_traces: boolAlso fetch traces for the same block range (no-op since traces are already fetched).
include_blocks: boolAlso fetch block headers for the same block range.